@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: pixmaped-resize.pl,v 1.17 1999/03/16 20:40:29 root Exp $
+# $Id: pixmaped-resize.pl,v 1.19 1999/03/23 22:12:23 root Exp $
 
 # Copyright (c) Mark Summerfield 1999. All Rights Reserved.
 # May be used/distributed under the same terms as Perl.
@@ -273,7 +273,7 @@ sub close {
         }
     }
 
-    &cursor( -1 ) ;
+    &cursor() ;
     &grid::status( '' ) ;
     $ResizeWin->destroy ;
 }
